#!/usr/bin/env python3


'''
Main import file used when 'import meraki_cli'
'''


from . import __version__


name = "meraki_cli"
__version__ = __version__.version
